ytree\.arbor\.io\.TreeFieldIO
=============================

.. currentmodule:: ytree.arbor.io

.. autoclass:: TreeFieldIO

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TreeFieldIO.__init__
      ~TreeFieldIO.get_fields
   
   

   
   
   